# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Merge request types:
### Added
When a new feature is added.
### Fixed
When a bug is fixed.
### Changed
When a funcionality is changed.

## [Unrealeased]

## [14.0.1.0.2] - 15/06/2023
### Fixed
- [#5](https://git.coopdevs.org/coopdevs/odoo/odoo-addons/enhancements/enhancements-crm/-/merge_requests/5) Create opportunity instead of lead and remove metadata as column field on crm lead creation
